package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````+1Y```````!``````````,B>````
M`````````$``.``(`$``'``;``8````$````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````#"9````````,)D`````````
M$`````````$````&````,)D````````PJ4```````#"I0```````4`0`````
M``#Q!``````````0`````````@````8````PF0```````#"I0```````,*E`
M`````````@`````````"````````"``````````$````!````!@"````````
M&`)````````8`D```````#@`````````.``````````$`````````%#E=&0$
M````1)@```````!$F$```````$280```````[`````````#L``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$``````````O;&EB97AE8R]L9"UE;&8N<V\N,@`````*````
M!`````$```!$<F%G;VY&;'D```"\*0D`"@````0````@````1')A9V]N1FQY
M`````````````````````````````````````````!D````2````````````
M`````````````#(````2`````````````````````````#@````2````````
M`````````````````$D````2`````````````````````````%`````2````
M`````````````````````%@````2`````````````````````````'(````2
M`````````````````````````(H````2`````````````````````````*0`
M```2`````````````````````````*D````2````````````````````````
M`+L````2`````````````````````````,L````2````````````````````
M`````-0````2`````````````````````````.,````2````````````````
M`````````.X````2`````````````````````````/P````2````````````
M``````````````0!```2``````````````````````````X!```2````````
M`````````````````!4!```2`````````````````````````",!```2````
M`````````````````````"X!```2`````````````````````````#\!```2
M`````````````````````````$8!```2`````````````````````````&8!
M```2`````````````````````````&T!```2````````````````````````
M`'P!```2`````````````````````````*D!```2````````````````````
M`````+@!```2`````````````````````````,L!```2````````````````
M`````````-(!```2`````````````````````````-X!```2````````````
M`````````````/,!```2`````````````````````````/H!```2````````
M``````````````````8"```2`````````````````````````!8"```2````
M`````````````````````!T"```2`````````````````````````"("```2
M`````````````````````````"<"```2`````````````````````````#`"
M```2`````````````````````````#@"```2````````````````````````
M`#T"```6`````````````````````````$,"```2````````````````````
M`````$H"```2`````````````````````````%`"```2````````````````
M`````````&4"```2`````````````````````````'\"```2````````````
M`````````````(<"```2`````````````````````````)`"```2````````
M`````````````````)@"```2`````````````````````````+H"```2````
M`````````````````````,`"```2`````````````````````````,4"```2
M`````````````````````````,L"```2`````````````````````````.8"
M```2`````````````````````````$8#```2````````````````````````
M`%0#```2`````````````````````````&,#```2````````````````````
M`````(H#```2`````````````````````````)4#```6````````````````
M`````````+@#```@`````````````````````````-(#```@````````````
M`````````````*@#```2````$!E``````````````````/D#```1`!0`.*U`
M```````(`````````+\!```2``P`8#=```````!1`````````%@"```2``P`
MP"Y```````"-!@```````/0#```2``P`H!M````````!`@```````!,$```2
M``T`"%)``````````````````"`#```2``P``"A```````#O`0```````"T#
M```2``P`\"=````````#`````````'0#```2``P`4#5````````#`@``````
M`.X#```2``H`N!=```````````````````8````0`!$`@*U`````````````
M``````$````0`!$`(:Y``````````````````+`````2``P`0$Y```````"@
M`0```````&T"```2``P`$"Y```````"P`````````-X"```2``P`,"Q`````
M``"K`````````.P"```2``P`T"M```````!9`````````!,#```2``P`\"E`
M```````B`````````#X#```2``P`P"=````````H`````````(4!```2````
M\!I```````````````````<#```2``P`("I```````!$`````````!(````0
M`!$`@*U``````````````````#4!```1`!0`6*U````````(`````````)8!
M```2````X!I```````````````````P$```2``P`+1Y```````!-`0``````
M`,(````2``P`X$U```````!4``````````0$```1`!@`@*U````````(````
M`````)\"```2``P`\"U````````=`````````-0"```1`!@``*Y````````(
M`````````)H````2``P`X$]```````#U`0```````%D!```1`!@`(*Y`````
M```!`````````/H"```2``P`<"I```````!<`0```````&`````1`!@`P*U`
M``````!```````````!?96YD`%]?8G-S7W-T87)T`%]E9&%T80!M86QL;V,`
M1$8T,#0N,`!L:6)C+G-O+C@`86)O<G0`7U]S=&%C:U]C:&M?9F%I;`!S=')L
M96X`;65M;6]V90!S=')N8VUP`%]?<W1A8VM?8VAK7V=U87)D`%]I;FET7W1L
M<P!$1G!R:79A=&5?,2XP`%]R=&QD7V-A;&Q?:6YI=`!S:&%?9FEN86P`97AI
M=`!M96UC<'D`<VAA7W5P9&%T90!A=&5X:70`<VAA7VEN:70`<&5R;%]R=6X`
M<&5R;%]C;VYS=')U8W0`<&5R;%]A;&QO8P!097)L7W-Y<U]T97)M`'-T<G)C
M:'(`<&5R;%]F<F5E`'-T<F1U<`!P97)L7V1E<W1R=6-T`'!E<FQ?<&%R<V4`
M<W1P8W!Y`&UY7W!A<E]P;`!M96UC:'(`4&5R;%]S869E<WES;6%L;&]C`%!,
M7V1O7W5N9'5M<`!A8V-E<W,`<'1H<F5A9%]A=&9O<FL`<F5A9&QI;FL`4&5R
M;%]A=&9O<FM?;&]C:P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]S>7-?:6YI
M=#,`<W1R=&]K`'!A<E]C;&5A;G5P`'-T<F-M<`!097)L7VUG7W-E=`!097)L
M7V-R;V%K7VYO8V]N=&5X=`!S=')C:'(`4&5R;%]G971?<W8`4&5R;%]G=E]F
M971C:'!V`&=E='!I9`!F<F5E`&]P96X`8VQO<V5D:7(`9G!R:6YT9@!S=&%T
M`&5R<FYO`'5N;&EN:P!M:V1I<@!R96%D9&ER`'!A<E]M:W1M<&1I<@!S<')I
M;G1F`'!A<E]S971U<%]L:6)P871H`')E86QL;V,`9V5T<'=U:60`;W!E;F1I
M<@!G971U:60`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`;'-T870`<F5A
M9`!L<V5E:P!V9G!R:6YT9@!?7W-T9&5R<G``<&%R7V1I90!R;61I<@!P87)?
M96YV7V-L96%N`'!A<E]I;FET7V5N=@!P87)?9&ER;F%M90!P87)?8F%S96YA
M;64`<&%R7V9I;F1P<F]G`'!A<E]C=7)R96YT7V5X96,`>'-?:6YI=`!097)L
M7W-V7W-E='!V`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?;F5W6%-?9FQA9W,`6%-?
M26YT97)N86QS7U!!4E]"3T]4`%!E<FQ?;F5W6%,`4$Q?8W5R<F5N=%]C;VYT
M97AT`&)O;W1?1'EN84QO861E<@!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?:6YI=`!M86EN`%]?<')O
M9VYA;64`96YV:7)O;@!?<W1A<G0`7V9I;FD`;&EB<&5R;"YS;RXU+C,V`&QI
M8G!T:')E860N<V\N,`!L:6)D;"YS;RXP`&QI8FTN<V\N-`!L:6)C<GEP="YS
M;RXT`&QI8G5T:6PN<V\N-``O=7-R+VQI8B]G8V,X,#HO=7-R+VQO8V%L+VQI
M8B]P97)L-2\U+C,V+VUA8V@O0T]210``````$0```#X````$````"````"`<
M$``%0`2`*```!("&`8S"H0$B20`$&XB".$&Z!`((/@```$````!$````2```
M`$D```!0````40```%(```!4````50```%8```!7````6````%H```!;````
M`````%T```!Z\$IKO5!VGF[%WQ_.WD<M:G^:?.O3[PX@_^0.+L6;MM1DU'RY
MC?$.V7%8'+KCDGQ"^M>'^J%L8)A/PYNR`8MOXD?&`</E/RR'^9R!9Z_,9D)%
MU>R)!W#3R=6R<3-BV^T5C"7,I]VC:WZIG)OG%0.#:QJ>4`J*$%>CX/M)(6)D
M!P```@`"``(``@`"``(``P`#``(``@`"`````````````@````(```````(`
M`@````(``@`"`````@`"```````"```````"``(``@`"``(``@`"``(``@`"
M``(``@`"``(``@`"``(``@`"``(```````````````````````$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0````$``0`!`````0`!``$``0`"
M``$``0`!``(``0`"`"@````0`````````%`WEP@```(`(````!````"0M'X`
M```#`'P`````````.*M````````2````*0``````````````,*M````````2
M````.P```````````````*Y````````%````60``````````````(*Y`````
M```%````6P``````````````P*U````````%````70``````````````6*M`
M```````'`````@``````````````8*M````````'````!P``````````````
M:*M````````'````"```````````````<*M````````'````"P``````````
M````>*M````````'````"0``````````````@*M````````'````!@``````
M````````B*M````````'`````P``````````````D*M````````'````!```
M````````````F*M````````'`````0``````````````H*M````````'````
M!0``````````````J*M````````'````+@``````````````L*M````````'
M````,```````````````N*M````````'````+```````````````P*M`````
M```'````+0``````````````R*M````````'````*```````````````T*M`
M```````'````*@``````````````V*M````````'````)```````````````
MX*M````````'````)@``````````````Z*M````````'````-@``````````
M````\*M````````'````/@``````````````^*M````````'````.@``````
M`````````*Q````````'````,@``````````````"*Q````````'````&```
M````````````$*Q````````'````&@``````````````&*Q````````'````
M%@``````````````(*Q````````'````.```````````````**Q````````'
M````-P``````````````,*Q````````'````%0``````````````.*Q`````
M```'````$```````````````0*Q````````'````$@``````````````2*Q`
M```````'````(```````````````4*Q````````'````'```````````````
M6*Q````````'````'0``````````````8*Q````````'````-0``````````
M````:*Q````````'````-```````````````<*Q````````'````,P``````
M````````>*Q````````'````,0``````````````@*Q````````'````+P``
M````````````B*Q````````'````*P``````````````D*Q````````'````
M)P``````````````F*Q````````'````)0``````````````H*Q````````'
M````(P``````````````J*Q````````'````(@``````````````L*Q`````
M```'````(0``````````````N*Q````````'````'P``````````````P*Q`
M```````'````'@``````````````R*Q````````'````.0``````````````
MT*Q````````'````&P``````````````V*Q````````'````5```````````
M````X*Q````````'````4```````````````Z*Q````````'````&0``````
M````````\*Q````````'````%P``````````````^*Q````````'````%```
M`````````````*U````````'````$P``````````````"*U````````'````
M$0``````````````$*U````````'````#P``````````````&*U````````'
M````#@``````````````(*U````````'````#0``````````````**U`````
M```'````#```````````````,*U````````'````"@``````````````2(/L
M".AX"```Z`\Z``!(@\0(PP``````_S5RDP``_R5TDP``D)"0D/\E<I,``&@`
M````Z>#_____)6J3``!H`0```.G0_____R5BDP``:`(```#IP/____\E6I,`
M`&@#````Z;#_____)5*3``!H!````.F@_____R5*DP``:`4```#ID/____\E
M0I,``&@&````Z8#_____)3J3``!H!P```.EP_____R4RDP``:`@```#I8/__
M__\E*I,``&@)````Z5#_____)2*3``!H"@```.E`_____R4:DP``:`L```#I
M,/____\E$I,``&@,````Z2#_____)0J3``!H#0```.D0_____R4"DP``:`X`
M``#I`/____\E^I(``&@/````Z?#^____)?*2``!H$````.G@_O___R7JD@``
M:!$```#IT/[___\EXI(``&@2````Z<#^____)=J2``!H$P```.FP_O___R72
MD@``:!0```#IH/[___\ERI(``&@5````Z9#^____)<*2``!H%@```.F`_O__
M_R6ZD@``:!<```#I</[___\ELI(``&@8````Z6#^____):J2``!H&0```.E0
M_O___R6BD@``:!H```#I0/[___\EFI(``&@;````Z3#^____)9*2``!H'```
M`.D@_O___R6*D@``:!T```#I$/[___\E@I(``&@>````Z0#^____)7J2``!H
M'P```.GP_?___R5RD@``:"````#IX/W___\E:I(``&@A````Z=#]____)6*2
M``!H(@```.G`_?___R5:D@``:",```#IL/W___\E4I(``&@D````Z:#]____
M)4J2``!H)0```.F0_?___R5"D@``:"8```#I@/W___\E.I(``&@G````Z7#]
M____)3*2``!H*````.E@_?___R4JD@``:"D```#I4/W___\E(I(``&@J````
MZ4#]____)1J2``!H*P```.DP_?___R42D@``:"P```#I(/W___\E"I(``&@M
M````Z1#]____)0*2``!H+@```.D`_?___R7ZD0``:"\```#I\/S___\E\I$`
M`&@P````Z>#\____)>J1``!H,0```.G0_/___R7BD0``:#(```#IP/S___\E
MVI$``&@S````Z;#\____)=*1``!H-````.F@_/___R7*D0``:#4```#ID/S_
M__\EPI$``&@V````Z8#\____);J1``!H-P```.EP_/___R6RD0``:#@```#I
M8/S___\EJI$``&@Y````Z5#\____):*1``!H.@```.E`_/___R6:D0``:#L`
M``#I,/S__U-(@^PP2(L%%)(``$B)1"0H,<")?"0<2(U\)!Q(B70D$$B-="00
M2(E4)`A(C50D".C[_O__NN`:0`"_\!I``$B)UN@9____@#TRD@````^$$`$`
M`&1(BQ0E`````$B+!2R/``!(BP0"@(BR`P```XM$)!R->`2-6`-(8_](P><#
MZ.O^__](BWPD$(M,)!Q(B05SD0``2(L72,=`"`]40`!(QT`8$E1``$B)$$B+
M%0:1``!(B5`0@_D!#XXI`0``2(/'"(/!`[X$````#Q]$``!(BQ=,8\:#Q@%(
M@\<(2HD4P#G.=>M(8_9(P>8#2,<$,`````!%,<!(B<&)VDB+/0V1``"^0"5`
M`.AS_O__A<`/A(@```!(BSWTD```Z&_^__](C70D)+^Y4D``B<,QP.B,`P``
M2(7`='5(BSW0D```Z%O^___H9O[__XG82(M<)"A(,QW(D```#X6>````2(/$
M,%O#Z%?^__](B06@D```2(7`='U(B<?H4_[__TB+!0R.``!D2(L4)0````!(
MBPP"QH'_"````.G'_O__2(L];)```.@W_O__Z6?___](BSU+D```2(7_=`KH
M`1H``.EU____OV=20`!(C70D).CM`@``2(G'2(D%(Y```$B%P`^$4____^O2
MOB````#I^O[__[\!````Z(3Z___HG_K__[@`````2#T`````<SI52(GE0513
M@SU,XK__)74@2(G#3(LC_U,028D$)$B#PQA(@?L`````<PN#>P@E=./H_?G_
M_UM!7%W#PU5(B>532(/L"+@`````2"T`````2,'X`TB)PW41Z/TS``!(@\0(
M6UW#2(7;=.](@^L!2(L$W0````!(@_@!=NG_T.OE54B)Y4%7059!54%44TB#
M[!A(B?-,BR]%B>],C7<(26/%3(UDQQ!(@STECP```'17187M?A=(BT<(2(7`
M=`Y(B07&C@``#[80A-)U3^AR^?__Z'WY__^X,*E``$B%P'1-2(G?Z'OY__^X
M,*E``$B%P'1"3(GB3(GV1(GOZ//\__^)Q^AL^?__3(DEQ8X``.N@2(/``0^V
M$(32=+&`^B]U\$B-4`%(B15@C@``Z^/HPO[__^NTO^D=0`#H)?G__[@`````
M2"T`````2,'X`TB)1<AT++L`````ZPI(@\,!2#E=R'0;2(L$W0````!(@_@!
M=NA,B>),B?9$B?__T.O;Z(?X__^X`````$@M`````$C!^`-(B47(#X15____
MNP````#K#DB#PP%(.5W(#X1`____2(L$W0````!(@_@!=N1,B>),B?9$B?__
MT.O7N("M0`!(/8"M0`!T%[@`````2(7`=`U52(GEOX"M0`#_T%W#P[Z`K4``
M2('N@*U``$C!_@-(B?!(P>@_2`'&2-'^=!>X`````$B%P'0-54B)Y;^`K4``
M_]!=P\.`/:N-````=5E52(GE0513NWBM0`!(@>MPK4``2,'[`TB#ZP%!O'"M
M0`!(BP6)C0``2#G8<QM(@\`!2(D%>8T``$'_%,1(BP5NC0``2#G8<N7H3O__
M_\8%58T```%;05Q=P\-52(GEZ%W___]=PV9F9F8N#Q^$````````````````
M``````````!!5T%6055!5%532(/L"$B%_P^$JP```$R+/0*-``!-A?\/A)L`
M```/M@>$P'0$/#UU7D4QY$F+'TB%VW0Y28GU28G^36/D3(G]#Q^``````$R)
MXDR)]DB)W^AR]___A<!U!T*`/",]=$=(@\4(2(M=`$B%VW7:2(/$"$B)V%M=
M05Q!74%>05_##Q^$``````!)B?Q)@\0!00^V!"2$P'0$/#UU[T$I_.N,#Q^`
M`````$PI_4J-7",!2,']`T&);0#KM#';Z[!F+@\?A```````4TB)^TB#[!!(
MBP6!C```2(E$)`@QP&8N#Q^$```````QP$B-="0$2(G?Z`'___](A<!T+DAC
M5"0$2(L%$(P``$B-!-!(BU`(2(D02(72=-!(@\`(2(M0"$B)$$B%TG7PZ[Y(
MBT0D"$@S!2*,``!U!DB#Q!!;P^B5]O__#Q]$``!!5T%6055!5%5(B?532(G[
M2(/L*$B+!?6+``!(B40D&#'`,<"`/CT/E,!(`<5(B>_H:_;__TB-="042(G?
M28G$,<#H:?[__TB%P`^$!`$``$B)QTF)Q>A%]O__3#G@#X/0````3&-T)!1)
MP>8##[8#A,`/A)P!```\/0^$E`$``$B)V$B#P`$/MA"$TG0%@/H]=?!(*=A(
MF$J-?"`"3`,U+(L``.@']O__28D&2(7`#X1S`0``2(L%%(L``$AC5"042(U+
M`4B+%-`/M@.(`H3`="0\/74.ZQX/'X0``````(3`=!)(@\$!#[9!_TB#P@&(
M`CP]=>K&`CTQP`\?1```#[9,!0"(3`(!2(/``83)=>\QP$B+7"082#,=\8H`
M``^%#0$``$B#Q"A;74%<05U!7D%?PS'`9BX/'X0```````^V5`4`08A4!0!(
M@\`!A-)U[NN]3(L]=8H``$F#/P`/A+8```!,B?@QTNL'#Q]``$2)ZDB#P`A$
MC6H!2(,X`'7OC7(#2&/V2,'F`XL%5XH``(7`=5O'!4F*```!````2(GWZ`GU
M__](A<!T?$UCQ4R)_DB)QTZ--,4`````3(E$)`A,B?+H]O3__TR+1"0(2(D%
M^HD``$B)P4K'1,$(`````$2);"04Z8'^__\/'T``3(G_Z-CT__](B<%(B07.
MB0``2(7`="%-8\5.C33%`````.O%,<#I??[__[X0````13'MZ6/___^X____
M_^GA_O__Z%GT__]F#Q^$``````!!54%455-(@>R8````2(L%O(D``$B)A"2(
M````,<!(A?]T"(`_`$B)_74E2(N$)(@```!(,P66B0``#X7\````2('$F```
M`%M=05Q!7<-FD.A+]/__28G$2(7`=,Y,B>?H2_3__TB%P`^$L@```$B-6!"_
M&5)``+D"````2(G>\Z8/E\`<`(3`=-._&U)``+D#````2(G>\Z8/E\`<`(3`
M=+M(B>_HMO/__TB)WTF)Q>BK\___08U\!0)(8__HKO/__TB)V4B)ZKX>4D``
M28G%2(G',<#HYO/__TR)[TB)YNCK\___3(GO@_C_=`\/MT0D$&8E`/!F/0!`
M=#GHW_/__TR)[^CG\___3(GGZ)_S__](A<`/A53___]F#Q]$``!,B>?HV//_
M_TB)[^C@\___Z?;^___HQO[__^O%Z`_S__]F9BX/'X0```````\?0`!5N:"2
M0`"Z$!E``+XD4D``4TB#[`A(BQW4A0``9$B++"4`````2(M\'0#HL?/__TB+
M?!T`0;@84D``2(/$"%M%,<E,B<&Z4#5``+Y`4D``7>DK]?__9F8N#Q^$````
M``!32(G[2('LD````$B+!0Z(``!(B80DB````#'`2(GFZ&SS__^%P'4X#[=4
M)!"!X@#P``"!^@!```!T"('Z`*```'4?O@(```!(B=_H4//__X7`#Y3`#[;`
MZPAF#Q]$```QP$B+C"2(````2#,-KX<``'4)2('$D````%O#Z!_R__]F9BX/
M'X0```````\?0`!!5;K_`P``28GU051)B?R_55)``%532('L&`0``$B+!6R'
M``!(B80D"`0``#'`2(GFZ.KR__^%P'YVC5#_2(L-O(0``&1(BS0E`````$AC
MVH`\'`!(BRP.=4F%TG1F2(G:OB\```!(B>?HPO+__TB%P'112(G92(GB3(GF
M2(GOZ+SR__](BX0D"`0``$@S!?V&``!U/TB!Q!@$``!;74%<05W#2&/8Z[8/
M'X0``````&1(BQ0E`````$B+!4"$``!(BRP"3(GJ3(GF2(GOZ'[R___KL.@W
M\?__#Q^``````%-(B?Y(@>P0!```2(L%GH8``$B)A"0(!```,<!(B>-(B=_H
M6?+__TB#Z`%(.=AW#NL1Q@``2(/H`4@YV'0%@#@O=.^^+P```$B)W^A`\O__
M2(7`=#!(.=AW)DB)W^@^\O__2(N4)`@$``!(,Q4_A@``=35(@<00!```6\,/
M'T``Q@``Z]5(BX0D"`0``$@S!1R&``!U$DB!Q!`$``"_&5)``%OI^/'__^B#
M\/__#Q\`9$B+%"4`````N:"20`"^)%)``$B+!5:#``!(BSP"NA`90`#I./'_
M_P\?A```````,<##9F8N#Q^$``````!FD$%528G]OV=20`!!5%532(GS2('L
MF`0``$B+!:&%``!(B80DB`0``#'`2(GFZ"_X__^^+P```$R)[TB)Q>A_\?__
M2(7`=#I,B>Z_<%)``#'`Z%OY__],B>A(BY0DB`0``$@S%5F%```/A7T!``!(
M@<28!```6UU!7$%=PP\?1```2(G?Z"CQ__^^?5)``$B)Q^@[\?__2(G#2(7`
M=*F`.P`/A-L```!F+@\?A```````2(7M=!-(B=Y(B>_H(/'__X7`#X28````
M2(G?Z(#O__](C4P#_TF)Q$@YRW,C@#DO=`?K'(`Y+W4,Q@$`2(/I`4@YRW7O
M2(G?Z%/O__])B<1,B>_H2.___TF-1`0!2#W_`P``#X<M____OH%20``QP$V)
MZ+E_4D``2(V\)(````!(B=KH>.___TB)YDB-O"2`````Z'CO__^%P'44#[=$
M)!!F)0#P9CT`@'15#Q]$``"^?5)``#'_Z&3P__](B<-(A<`/A,[^__^`.P`/
MA2____](A>UT&;D"````OQE20`!(B>[SI@^7PH#:`(32=,%!O`$```"[&5)`
M`.E1____D+X!````2(V\)(````#H?N___X7`=9I(C;0D@````+]P4D``Z-CW
M__](C;PD@````.C+[___Z6[^___H4>[__Y!3OB\```!(B?OHHN___TB-4`%(
MA<!(#T7:2(G?6^F>[___9F8N#Q^$```````/'P!(A?]T*X`_`'0F4TB)^^@=
M[O__2(/``4@]``0``'<A2(G?6^G(_/__#Q^$``````"_&5)``.E6[___9@\?
M1```,<!;PV9F+@\?A```````D$B#[!B_B%)``$B+!4"#``!(B40D"#'`Z*3V
M__\QP+^14D``Z)CV__\QP+^94D``Z(SV__\QP+^B4D``Z(#V__\QP+^I4D``
MZ'3V__\QP+^Y4D``Z&CV__\QP+]G4D``Z%SV__\QP+_%4D``Z%#V__\QP+_/
M4D``Z$3V__\QP+_94D``Z#CV__\QP+]P4D``Z"SV__\QP$B-="0$O^-20`#H
M2_7__TB%P'0/2(G&O\]20``QP.B']O__,<!(C70D!+_T4D``Z";U__](A<!T
M#TB)QK\&4T``,<#H8O;__S'`2(UT)`2_$5-``.@!]?__2(7`=#Q(B<:_9U)`
M`#'`Z#WV__\QP+XR4T``OZE20`#H+/;__TB+1"0(2#,%,((``'4U2(/$&,-F
M#Q^$```````QP$B-="0$OR%30`#HK_3__TB%P'2]2(G&O\520``QP.CK]?__
MZZSH=.S__P\?0`!(@^P8O\520`!(BP7@@0``2(E$)`@QP$B-="0$Z&_T__](
MA<!T*@^V$(#Z,`^4P(32#Y3""="#\`$/ML!(BTPD"$@S#:B!``!U"DB#Q!C#
MD#'`Z^CH%^S__P\?@`````!(@>S8````2(ET)"A(B50D,$B)3"0X3(E$)$!,
MB4PD2(3`=#</*40D4`\I3"1@#RE4)'`/*9PD@`````\II"20````#RFL)*``
M```/*;0DL`````\IO"3`````2(L%+H$``$B)1"08,<!(B?Y(C80DX````$B+
M/56!``!(B40D"$B)XDB-1"0@QP0D"````,=$)`0P````2(E$)!#H'^W__[__
M````Z$7K__\/'T0``$%4N@(````Q]D&)_%532('L$``!`$B+!<2```!(B80D
M"``!`#'`2(GEZ/+L__](@^@!2(G!2,'Y/TC!Z3!(C10(#[?22"G*2"G02(G#
M#XB1````,=)(B=Y$B>?HP.S__TB#^/\/A(\```"Z"``!`$B)[D2)Y^BV[/__
M@_C_=&Y(F$B#^`=V24B-1`7X2#GH<POK/4B#Z`%(.>AR-$B+#<5_``!(.0AU
MZT@IZ$@!V$B+M"0(``$`2#,U(X```'5&2('$$``!`%M=05S##Q]$``!(@>L`
M``$`2('[``#__P^%;____TC'P/_____KP;]!4T``,<#H5_[__[\T4T``,<#H
M2_[__^A6ZO__9@\?1```2(/L".@G[/__B<?H,.S__TB%P'0#2(L`2(/$",,/
M'P!!5%5(B?V_35-``%-(@^P02(L%F7\``$B)1"0(,<!(C70D!.@H\O__2(7`
M=`B`.`!(B<-U*TB)[K]-4T``,<#H7//__TB+1"0(2#,%8'\``'592(/$$%M=
M05S##Q]$``!(B>_HV.G__TB)WTF)Q.C-Z?__28U\!`+HT^G__TF)V+E]4D``
M2(GJ28G$2(G'OH%20``QP.@&ZO__3(GFOTU30``QP.CW\O__ZYGH@.G__T%6
M055)B?V_9U)``$%455-(@>Q0`0``2(L%XGX``$B)A"1(`0``,<!(C70D$$C'
MA"20````:5-``$C'A"28````&5)``$C'A"2@`````````$C'A"30````!E-`
M`$C'A"38````;U-``$C'A"3@````=E-``$C'A"3H````?E-``$C'A"3P````
M@U-``$C'A"3X`````````$C'A"2P````75-``$C'A"2X````AU-``$C'A"3`
M`````````.C>\/__2(7`=`F`.``/A6`$```QP.A9_O__2(G#2(7`#X3=`P``
M2(G?Z*7H__](C7P``>BKZ/__@#L`28G$="),B>4/MA-(B>\QP+Z04T``2(/#
M`4B#Q0+HUNC__X`[`'7A2(V<)-@```"_!E-``.L39I!(@\,(2(M[^$B%_P^$
M<P$``$B-="00,<#H4_#__TB)Q4B%P'3;@#@`=-9(B<?H?O7__X7`=,I(B>_H
M@NG__TB)PTB%P`^$.@$``&8/'T0``$B)WHL62(/&!(V"__[^_O?2(=`E@("`
M@'3IB<+!ZA"I@(````]$PDB-5@)(#T3RB<$`P4R)X4B#W@-(*=Z+.4B#P02-
MA__^_O[WUR'X)8"`@(!TZ8G"P>H0J8"````/1,)(C5$"2`]$RHG"`,)(@]D#
M3"GAC:P.!`0``$AC[4B)[^B:Y___OII30`!-B>%(B=I(B<=)B<9!N)530``Q
MP+E_4D``Z,?G__^^P`$``$R)]^A*Z?__@_C_=1YD2(L4)0````!(BP4M>@``
M1(L$`D&#^!$/A;4"``!(C70D$$R)]^@*Z/__B<.%P`^$L````$F+50!(BSW%
M?```3(GQ,<"^8%1``#'MZ`3I__](BXPD2`$``$@S#65\``!(B>@/A=@#``!(
M@<10`0``6UU!7$%=05[#,>UF+@\?A```````2&/%2(N<Q)````!(A=MT0(`[
M`'0[2(G?@\4!Z`#T__^%P'3<2(G?Z`3H__](B<-(A<`/A8C^__](8\5(BYS$
MD````$B%VW7(#Q^$```````QV^EI_O__9@\?A```````#[=$)"!F)0#P9CT`
M0`^%/?___T2+9"0DZ"/H__]!.<0/A2K___\/MT0D(&8E_P%F/<`!#X47____
M2(GOZ#_F__](C70D$+^C4T``2(G%,<#H*^[__TB%P`^$\@$``$F+?0!(B<;H
MMO7__TF)Q$B%P`^$V@$``$R)Y^CRY?__@_@#?CU(8]"_J%-``+D%````28UT
M%/SSI@^7PH#:`(32=1^#^`0/A'("``"#Z`1(F$&`?`3_+P^$80(```\?1```
M,<#H*?G__X7`=15,B><Q]NBKY___08G$A<`/A7D!``"^,E-``+_%4D``,<#H
MW^[__^B:Y___N7]20`!,B?)(B>]!B<!!N1A20`"^S%-``#'`Z+KE___K3@\?
MA```````9$B+%"4`````2(L%*'@``(,\`A%U0NA5Y___2(/L"(/#`4R)\F@8
M4D``08G`08G9N7]20`"^VE-``$B)[S'`Z&SE__]86K[``0``2(GOZ.WF__^#
M^/]TJ$R)]^B`Y?__2(GNOV=20``QP.A![O__2(GOZ)GZ___IT/W__P\?0`"_
M75-``#'MZQ(/'X``````2&/%2(N\Q+````!(A?]T<DB-="00,<"#Q0'HL>S_
M_TB%P'3<@#@`=-=(B<?H[^7__TB)PTB%P'3'Z=7[__])BU4`2(L])WH``$R)
M\3'`OAA40``Q[>AFYO__Z5W]__^02(G'2(E$)`CH$_K__TB+1"0(2(G'Z*;E
M__](B<7I.OW__[\-````NV)30`#H/^3__TF)Q.F4^___#Q^``````$V+90#I
M'?[__XG'Z*#X__])B<5(A<`/B'3^__\QTDB-</9$B>?HIN7__[H&````2(VT
M)`H!``!$B>?HH>7__TB#^`8/A<@```"+!1E>```YA"0*`0``#X4T_O__#[<%
M"5X``&8YA"0.`0``#X4?_O__,=))C77.1(GGZ%'E__^Z*````$B-M"00`0``
M1(GGZ$SE__](@_@H=7=!N1A20`"Y?U)``$R)\C'`3(V$)!`!``"^O5-``$B)
M[\:$)#@!````Z+GC___I7/[__TV+;0A-A>T/A)?]__],B>_H/^/__TB#^`,/
MAH7]__])C70%_+^M4T``N04```#SI@^7P!P`A,!-#T3EZ63]___H_^+__[^R
M4T``,<#HX_;__P\?`$%4OZE20`!54TB#[!!(BQW,=0``9$B++"4`````2(L%
M3'@``$B)1"0(,<!(C70D!$B+1!T`#[:0L````(B0L0```#'`Z,?J__](A<!T
M"8`X,0^$2P$``#'`Z,+T__](BWP=`+D#````N@$```"^ZU-``.BYY/__28G$
M2(7`="A(BT`02(M\'0"Z[5-``$B+,.B;X___28M$)!!(BS#V1@Y`#X4I`0``
M2(M\'0"Y`P```+H!````OO)30`#H<.3__TF)Q$B%P'0O,<!(C70D!+]P4D``
MZ#?J__](A<`/A,\```!)BTPD$$B+?!T`2(G"2(LQZ#GC__](BWP=`+H!````
MOO130`#H->3__TB+?!T`N@E40`!(B<;H$^/__TB+1!T`2(UT)`2_9U)``,:`
ML0`````QP.C6Z?__2(D%#W<``$B%P'0ZOL`!``!(B<?HG>/__XU0`8/Z`78%
M@_@1=7](BT0D"$@S!01W```/A8P```!(@\006UU!7,,/'T0``$B+/=%V``#H
MY/?__TB)!;UV``!(A<!UKK^X5$``Z*[C__^`>`$`#X2R_O__Z:;^__])BT0D
M$$B+%9MV``!(BSA(BS+H&.___^DJ____#Q\`2(M\'0#HAN/__^G(_O__B<%(
MBP5P=@``2(L5878``+_@5$``2(LP,<#H4N/__^CMX/__9F8N#Q^$``````!F
MD%,QP$B)^^AE]/__2(7;=`F%P'0%@#L`=0=;PP\?1```2(G?Z)CR__](B<?H
M8/+__[^54T``N00```!(B<;SI@^7P!P`A,!UT4B)WUOI/^S__V9F9F9F9BX/
M'X0``````&9F9F9F9BX/'X0```````!!5TR-3SA!5D%505154TB![)@"``!(
MBP74=0``2(F$)(@"```QP$B)XDR-DH````!)B=!!BP%)BS%)@\`028/!"`_(
MB<!(B?%)B4#P2(GP2,'I($C!Z"A(P>XX)0#_``!("?!(B<Y(P>$(2,'F&('A
M``#_`(GV2`GP2`G(28E`^$TYPG6N2(VR``(```\?0`!(BT)H2#-"0$B#P@A(
M,T((2#-"^$B-#`!(P>@?2`G(@^#_2(E">$@Y\G753(L72(M?$$B+=R!(BV\8
M3(G03(G23(M/"$C!ZAM(P>`%2`G0`P0DC90PF7F"6DB)V$B+="0(2#'H3"'(
M2(VT-9EY@EI(,>A$C2P"3(G*3(G(2,'H`DC!XAY-B>A("<)(B=A)P>@;B=%(
M,<A,(=!(,=A(`?!,B>Y(P>8%3`G&1(TD!DR)UDR)T$C!YAY(P>@"38GC2`GP
M2(MT)!!)P>L;2#'"08G`3"'J2(VT,YEY@EI(,<I(`?),B>9(P>8%3`G>1(T<
M%DR)[DG![0)(BU0D&$C!YAY,">Y(C901F7F"6DR)V4@Q\$&)]DPAX$PQP$C!
MZ1M(`=!,B=I(P>(%2`G*3(GA2<'L`DC!X1Y$C2P"2(GP2(M4)"!,">%,B>Y(
M,<A)C900F7F"6DC![AM!B<Q,(=A,,?!(`=!,B>I(P>(%2`GR1(T$`DR)VDG!
MZP)(BT0D*$C!XAY,B<9,"=I)C80&F7F"6DC![AM(,=%!B=-,(>E,,>%(`<%,
MB<!(P>`%2`GP1(TT"$R)Z$G![0)(BTPD,$C!X!Y,B?9,">A)C8P,F7F"6D@Q
MPD&)Q4PAPDPQVD@!RDR)\4C!X05(P>X;2`GQ3(G&2<'H`DC!YAY$C2012(M4
M)#A,"<9,B>%(,?!)C903F7F"6DC!Z1M!B?!,(?!,,>A(`=!,B>)(P>(%2`G*
M3(GQ2<'N`DC!X1Y$C1P"2(GP2(M4)$!,"?%,B=Y(,<A)C905F7F"6DC![AM!
MB<Y,(>!,,<!(`=!,B=I(P>(%2`GR1(TL`DR)XDG![`)(BT0D2$C!XAY,B>Y,
M">))C80`F7F"6DC![AM(,=%!B=1,(=E,,?%(`<%,B>A(P>`%2`GP1(T$"$R)
MV$G!ZP)(BTPD4$C!X!Y,B<9,"=A)C8P.F7F"6DC![AM(,<)!B<-,(>I,,>)(
M`<I,B<%(P>$%2`GQ3(GN2<'M`DC!YAY$C3012(M4)%A,">Y,B?%(,?!)C904
MF7F"6DC!Z1M!B?5,(<!,,=A(`=!,B?)(P>(%2`G*3(G!2<'H`DC!X1Y$C20"
M2(GP2(M4)&!,"<%,B>9(,<A)C903F7F"6DC![AM!B<A,(?!,,>A(`=!,B>)(
MP>(%2`GR1(T<`DR)\DB+1"1H2,'B'DG![@),B=Y,"?))C80%F7F"6DC![AM(
M,=%!B=9,(>%,,<%(`<%,B=A(P>`%2`GP1(TL"$R)X$G![`)(BTPD<$C!X!Y,
MB>Y,">!)C8P(F7F"6DC![AM(,<)!B<1,(=I,,?)(`<I,B>E(P>$%2`GQ3(G>
M2<'K`DC!YAY$C0012(M4)'A,"=Y,B<%(,?!)C906F7F"6DC!Z1M!B?-,(>A,
M,>!(`=!,B<)(P>(%2`G*3(GI2<'M`DC!X1Y$C30"2(GP2(N4)(````!,">E,
MB?9(,<A)C904F7F"6DC![AM!B<U,(<!,,=A(`=!,B?)(P>(%2`GR1(TD`DR)
MPDG!Z`)(BX0DB````$C!XAY,B>9,"<))C80#F7F"6DC![AM(,=%!B=!,(?%,
M,>E(`<%,B>!(P>`%2`GP2(NT))````!$C1P(3(GP2<'N`DC!X!Y)C;0UF7F"
M6DV)W4P)\$G![1M(,<*)P4PAXDPQPD@!\DR)WDC!Y@5,">Z)]D@!\DR)YDG!
M[`)(P>8>08G53`GF3(ND))@```!(,?!,(=A/C80@F7F"6DV)[$@QR$G![!M,
M`<!-B>A)P>`%30G@18G`3`'`38G82<'K`DG!X!Y!B<1-"=A)B?.)]D@#M"2H
M````33'#1#':3(N<)*````!*C8P9H>O9;DV)XT@!T4R)XDG!ZQM(P>(%3`G:
MB=)(`=%,B>I)P>T"2,'B'D&)RTP)ZDV)Q46)P$P#A"2P````23'51#'H38G=
M2(VT!J'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'P3(GF2<'L`DC!YAY!B<5,">9)
MB=2)TDDQ]$0QX4V)[$@#E"2X````38V$"*'KV6Y,B>E)P>P;2,'A!4P)X8G)
M20'(3(G92<'K`DC!X1Y%B<1,"=E)B?.)]D@#M"3`````23'+1#'838GC2(V4
M`J'KV6Y,B>!)P>L;2,'@!4P)V(G`2`'"3(GH2<'M`DC!X!Y!B=-,">A)B<V)
MR4@#C"3(````23'%13'H38G=3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[HGV3`'&
M38G@2<'L`DG!X!Y!B?5-">!)B<2)P$TQQ$0QXDV)[$B-C!&AZ]EN3(GJ2,'B
M!4G![!M(`X0DT````$P)XHG22`'13(G:2<'K`DC!XAY!B<Q,"=I-B<-%B<!,
M`X0DV````$DQTT0QWDV)XTB-M#"AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!\$R)
M[DG![0)(P>8>08G#3`GN28G5B=)(`Y0DX````$DQ]40QZ4V)W4V-A`BAZ]EN
M3(G92<'M&TC!X05,">F)R4D!R$R)X4G![`)(P>$>18G%3`GA28GTB?9),<Q$
M,>!-B>Q(C90"H>O9;DR)Z$G![!M(P>`%3`G@B<!(`<),B=A)P>L"2`.T).@`
M``!(P>`>08G43`G828G+B<E(`XPD\````$DQPT4QV$V)XTZ-A`:AZ]EN3(GF
M2<'K&TC!Y@5,"=Z)]DP!QDV)Z$G![0))P>`>08GS30GH28G%B<!(`X0D^```
M`$TQQ40QZDV)W4B-C!&AZ]EN3(G:2<'M&TC!X@5,">J)TD@!T4R)XDG![`)(
MP>(>08G-3`GB38G$18G`23'41#'F38GL2(VT,*'KV6Y,B>A)P>P;2,'@!4P)
MX(G`2`'P3(G>2,'F'DG!ZP)!B<1,`X0D``$``$P)WDF)TXG22`.4)`@!``!)
M,?-$,=E-B>--C80(H>O9;DR)X4G!ZQM(P>$%3`G9B<E)`<A,B>E)P>T"2,'A
M'D6)PTP)Z4F)]8GV2`.T)!`!``!),<U$,>A-B=U(C90"H>O9;DR)V$G![1M(
MP>`%3`GHB<!(`<),B>!)P>P"2,'@'D&)U4P)X$F)S(G)23'$13'@38GL3HV$
M!J'KV6Y,B>Y)P>P;2,'F!4P)YHGV3`'&38G82<'K`DG!X!Y!B?1-"=A)B<-(
M`XPD&`$``(G`33'#2`.$)"`!``!$,=I-B>-(C8P1H>O9;DR)XDG!ZQM(P>(%
M3`G:B=)(`=%,B>I)P>T"2,'B'D&)RTP)ZDV)Q46)P$P#A"0H`0``23'51#'N
M38G=2(VT,*'KV6Y,B=A)P>T;2,'@!4P)Z(G`2`'P3(GF2<'L`DC!YAY!B<5,
M">9)B=2)TD@#E"0P`0``23'T1#'A38GL38V$"*'KV6Y,B>E)P>P;2,'A!4P)
MX8G)20'(3(G92<'K`DC!X1Y%B<1,"=E)B?.)]DDQRT0QV$V)XT@#M"0X`0``
M2(V4`J'KV6Y,B>!)P>L;2,'@!4P)V$2-'!!,B>A)P>T"2,'@'DP)Z$F)S8G)
M23'%B<)%,>A-B=U.C80&H>O9;DR)WDG![1M(P>8%3`GN3(NL)$`!``!&C30&
M38G@2<'L`DG!X!Y-">!,"<!$B<9)B<1(B=!((?!-(=Q)"<2XW+P;CTD!Q4P!
MZ4V)]4D!S$R)\4G![1M(P>$%3`GI28GU00',3(G92<'K`DC!X1Y,"=E!B<M)
M"<A-(?!-(=U-">A,BZPD2`$``$D!Q4P!ZDV)Y4D!T$R)XDG![1M(P>(%3`GJ
M1HTL`DR)\DG![@)(P>(>3`GR38G>08G02`G132'&3"'A3`GQ3(NT)%`!``!)
M`<9,`?9-B>Y(`?%,B>Y)P>X;2,'F!4P)]D2--`Y,B>9)P>P"2,'F'DP)YDV)
MQ(GQ2`GR22',3"'J3`GB3(ND)%@!``!)`<1-`>--B?1,`=I-B?-)P>,%2<'L
M&TT)XT6-)!--B>M)P>T"2<'C'DT)ZTF)S42)VDP)WDDAU4PA]DP)[DR+K"1@
M`0``20'%30'H38GE3`'&38G@2<'M&TG!X`5-">A%C2PP38GP2<'N`DG!X!Y-
M"?!)B=9$B<9-"<-)(?9-(>--"?-,B[0D:`$``$D!QDP!\4V)[DD!RTR)Z4G!
M[AM(P>$%3`GQ1HTT&4R)X4G![`)(P>$>3`GA28GT08G+20G(32'H32'<30G@
M3(ND)'`!``!)`<1,`>)-B?1)`=!,B?))P>P;2,'B!4P)XD:-)`),B>I)P>T"
M2,'B'DP)ZDV)W4&)T$@)T4TAQ4PA\4P)Z4R+K"1X`0``20'%3`'N38GE2`'Q
M3(GF2<'M&TC!Y@5,">Y$C2P.3(GV2<'N`DC!YAY,"?9-B<:)\4@)\DDASDPA
MXDP)\DR+M"2``0``20'&30'S38GN3`':38GK2<'C!4G![AM-"?-%C30338GC
M2<'L`DG!XQY-">-)B<Q$B=I,"=Y)(=1,(>Y,">9,BZ0DB`$``$D!Q$T!X$V)
M]$P!QDV)\$G![!M)P>`%30G@18TD,$V)Z$G![0))P>`>30GH28G51(G&30G#
M22'U32'S30GK3(NL))`!``!)`<5,`>E-B>5)`<M,B>%)P>T;2,'A!4P)Z4:-
M+!E,B?%)P>X"2,'A'DP)\4F)]DD)R$&)RTTAWDTAX$T)\$R+M"28`0``20'&
M3`'R38GN20'03(GJ2<'N&TC!X@5,"?)&C30"3(GB2<'L`DC!XAY,">)-B=Q!
MB=!("=%-(<1,(>E,">%,BZ0DH`$``$D!Q$P!YDV)]$@!\4R)]DG![!M(P>8%
M3`GF1(TD#DR)[DG![0)(P>8>3`GN38G%B?%("?))(<U,(?),">I,BZPDJ`$`
M`$D!Q4T!ZTV)Y4P!VDV)XTG![1M)P>,%30GK18TL$TV)\TG![@))P>,>30GS
M28G.1(G:3`G>22'63"'F3`GV3(NT)+`!``!)`<9-`?!-B>Y,`<9-B>A)P>X;
M2<'@!4T)\$6--#!-B>!)P>P"2<'@'DT)X$F)U$2)QDT)PTDA]$TAZTT)XTR+
MI"2X`0``20'$3`'A38GT20'+3(GQ2<'L&TC!X05,">%&C2093(GI2<'M`DC!
MX1Y,">E)B?5!B<M)"<A-(?!-(=U-">A,BZPDP`$``$D!Q4P!ZDV)Y4D!T$R)
MXDG![1M(P>(%3`GJ1HTL`DR)\DG![@)-B=A(P>(>3`GR08G62`G132'P3"'A
M3`G!3(N$),@!``!)`<!,`<9-B>A(`?%,B>Y)P>@;2,'F!4P)QD2-!`Y,B>9)
MP>P"3(GQ2,'F'DP)YD&)]$@)\DPAX4PAZD@)RDB+C"30`0``2`'!20'+3(G!
M2`.$)-@!``!,`=I-B<-(P>$%3`'P2<'K&TP)V8G)2`'*3(GI2<'M`DC!X1Y!
MB=-,">E-B>5!B<]("<Y-(?U,(<9,">Y-B=U(`?!,B=Y)P>T;2,'F!4P)[HGV
M2`'P3(G&2<'H`DC!YAY!B<5)"?"^UL%BRDPQP3'*2(N,).`!``!(`?%)`<Q,
MB>E,`>)-B>Q(P>$%2<'L&TP)X8G)2`'*3(G92,'A'DG!ZP)!B=1)"<M,B<%-
MB>9%B<!,,=E)P>X;,<A(BXPDZ`$``$@!\4D!STJ-##A,B>!(P>`%3`GPB<!,
MC30!3(GH2<'M`DR)V4C!X!Y%B?=%B=M)"<5(BX0D\`$``$PQZ4@!\#'*3(GY
M3`'`2,'I&T@!PDR)^$C!X`5("<A(BXPD^`$``(G`2`'"3(G@2`'Q2<'L`DC!
MX!Y,`=E-B>M!B=!,">!-B<1%B>U),<-)P>P;13'>3HT<,4R)P4C!X05,">&)
MR4D!RTR)^4G![P)(P>$>18G<20G/2(N,)``"``!(`?%,`>E)B<6)P$TQ_40Q
MZDR-+!%,B>),B>%(P>D;2,'B!4@)RDR)P4G!Z`*)TDC!X1Y)`=5(BY0D"`(`
M`$P)P4V)^$DQR$6)[D6)_T@!\D4QPT@!T$R)\DZ-!!A,B?!(P>H;2,'@!4@)
MT$B)RHG)B<!)`<!,B>!)P>P"2,'@'D6)PTD)Q$B+A"00`@``3#'B2`'P03'5
M3(G:3`'X20'%3(G82,'@!4C!ZAM("=!,B?))P>X"B<!(P>(>20'%2(N$)!@"
M``!,"?)%B>](`?!(`<A,B>%%B>1(,=%!,<A,B?E)`<!,B?A(P>D;2,'@!4@)
MR(G`20'`3(G82<'K`DC!X!Y%B<9)"<-(BX0D(`(``$R)\4C!Z1M(`?!,`>!)
MB=2)TDTQW$4QY4Z-)"A,B?!(P>`%2`G(2(N,)"@"``")P$D!Q$R)^$@!\4G!
M[P)(P>`>2`'*3(G918GE3`GX18G;2#'!03'(3(GI20'03(GJ2,'I&TC!X@5(
M"<J)TDD!T$R)\DG![@)(P>(>18G'20G62(N4)#`"``!,B?E(P>D;2`'R3`':
M28G#B<!-,?-%,=Q.C1PB3(GZ2,'B!4@)RDR)Z4G![0*)TDC!X1Y)`=-(BY0D
M.`(``$P)Z46)W$@!\D@!T$R)\D6)]D@QRD$QT$R)XDD!P$R)X$C!ZAM(P>`%
M2`G02(G*B<F)P$D!P$R)^$G![P)(P>`>18G%20G'2(N$)$`"``!(`?!,,?I,
M`?!!,=-,B>I)`<-,B>A(P>H;2,'@!4@)T$R)XDG![`*)P$C!XAY)`<-(BX0D
M2`(``$P)XD6)WDF)U$@!\$@!R$R)^46)_T@QT8G203'(2HT,`$R)\$V)\$G!
MZ!M(P>`%3`G`B<!(`<%,B>A)P>T"2,'@'D&)R$D)Q4B+A"10`@``33'L2`'P
M13'C38G$3`'X2<'L&TD!PTR)P$C!X`5,">")P$D!PTR)\$C!X!Y)P>X"18G<
M3`GP3(NT)%@"``!)`?9)`=9,B>I%B>U(,<(QT4F-%`Y,B>%-B>9)P>X;2,'A
M!4P)\8G)2`'*3(G!2<'H`DC!X1Y!B=9)"<A(BXPD8`(``$@!\4P!Z4F)Q8G`
M33'%13'K38GU20'+3(GQ2<'M&TC!X05,">F)R4D!RTR)X4G![`)(P>$>18G=
M20G,2(N,)&@"``!(`?%(`<A,B<%%B<!,,>$QRDB-#!!,B>A,B>I(P>H;2,'@
M!4@)T$R)\DG![@)(P>(>B<!)"=9(BY0D<`(``$@!P8G(2`'R3`'"38G@33'P
M13'#28G`3`':28G#2<'@!4G!ZQM-"=A)B<-(P>@"2<'C'D$!T$R)ZDG![0))
M"<-(BX0D>`(``$C!XAY)"=5$B>)!`=M(`?!$`>U,B5\02`'"3(GP2(EO&$PQ
MZ#'!2(T$"DR)PDR)P44!R$C!X@5(P>D;3(E'"$@)R@'000'"1`-W($R)%TR)
M=R!(BX0DB`(``$@S!?U?``!U$DB!Q)@"``!;74%<05U!7D%?P^ADRO__#Q]`
M`$B#[`B_@````.ARRO__NHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)4`A(B4@0
M2,=`&'94,A!(B7`@2,=`*`````!(QT`P`````,=`>`````!(@\0(PV9F+@\?
MA```````D$%72&/"059)B<9!54%428G\54F-;"0X4TB)\TB#[`A(BW<H2(M7
M,(T,QD@Y\4B)3RA(@](`2,'H'4@!T$B)1S!(8W]XA?]T5D&]0````$B)WD$I
M_44Y[D4/3NY(`>]-8_U,B?KHY\S__T&+1"1X1`'H08E$)'B#^$!T%4B#Q`A;
M74%<05U!7D%?PV8/'T0``$R)YT4I[DP!^^CRZ/__08/^/P^.W````$&#[D!%
MB?=!P>\&18G]28/%`4G!Y09)`=WS#V\#3(GG2(/#0`\110#S#V]+T`\131#S
M#V]3X`\152#S#V];\`\173#HH.C__TPYZW7,0<'G!D4I_DECQDB#^`AR6TF+
M50!)B50D.$F+5`7X2(E4!?A(C54(2(/B^$@IU4DI[4@!Q4B#Y?A(@_T(<AA(
M@^7X,<!)BTP%`$B)#`)(@\`(2#GH<NY%B70D>$B#Q`A;74%<05U!7D%?PY"H
M!'4H2(7`=.)!#[95`$&(5"0XJ`)TU$$/MU0%_F:)5`7^Z\=)B=WI</___T&+
M50!!B50D.$&+5`7\B50%_.NK059,C78X055!5%5(B?U32(M&*$B)\T2+9BA$
MBVXP2,'H`X/@/T$/S$$/S8U(`4B8QD0&.(!(8\%,`?"#^3@/CB`!``"Z0```
M`"G*B=%T#S'2B=:#P@'&!#``.<IR\TB)W^B*Y___9@_OP`\10SA)QT8P````
M`$$/$48000\11B!$B6MP2(G?1(EC=.A@Y___2(L#2(G?2,'H&(A%`$B+`TC!
MZ!"(10%(BP-(P>@(B$4"2(L#B$4#2(M#"$C!Z!B(101(BT,(2,'H$(A%!4B+
M0PA(P>@(B$4&2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,02,'H
M"(A%"DB+0Q"(10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&$C!Z`B(10Y(
MBT,8B$4/2(M#($C!Z!B(11!(BT,@2,'H$(A%$4B+0R!(P>@(B$422(M#(%N(
M11-=05Q!74%>Z9S'__^Z.````#'_*<J#^@AS+O;"!'5KA=(/A`'____&``#V
MP@(/A/7^__\QR6:)3!#^Z>G^__]F#Q^$``````")T4C'``````!(QT0(^```
M``!(C4@(2(/A^$@IR`'"@^+X@_H(#X*U_O__@^+X,<")QH/`"$B)/#$YT'+S
MZ9[^___'``````#'1!#\`````.F+_O__2(L%A%L``$B#^/]T)%5(B>532(/L
M"+M@K4``_]!(@^L(2(L#2(/X_W7Q2(/$"%M=P\,`2(/L".C%S?__2(/$",,`
M```N`"XN`"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E
M<FYA;',Z.E!!4CHZ0D]/5``O<')O8R]C=7)P<F]C+V5X90!005)?5$5-4`!0
M05)?4%)/1TY!344`.@`O`"5S)7,E<P!015),-4Q)0@!015),3$E"`%!%4DPU
M3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,
M14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?
M1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.`#$`;'-E96L@9F%I;&5D`')E860@9F%I;&5D`$Q$7TQ)
M0E)!4EE?4$%42`!54T52`%-94U1%30`O=&UP+P!435!$25(`5$5-4$1)4@!4
M14U0`%1-4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`4$%42`!P87)L
M`"YP87(`<VAO<G0@<F5A9``E<R5S8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S
M`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)
M3TX`,2XP-C,`+64`+2T`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````````````
M)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E
M(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E
M871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D
M1DE,15]O9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*
M)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@
M/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+
M6DE07TU!1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I
M8PI["FUY("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T
M.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ
M92TQ*2`M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@
M)'!O<R!I<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S
M(#X](#`I('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D
M8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`]
M(')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O
M<R`K("1I.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]
M"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#
M86-H92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I
M;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R
M7W1E;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@
M/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E
M;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM
M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A8
M6"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M
M92`]("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@
M=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@
M,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L
M;W-E("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D
M9FEL96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U
M=',H<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^
M("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]
M?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E
M;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G
M*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B
M)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[
M4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O
M<RP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("13
M24=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR
M87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL
M92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R
M97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2![
M"F]U=',H<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B
M(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&
M;W5N9"!005(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K
M(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#
M2$4B*3L*:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%
M04XB*2!["F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!
M1TE#.PI]"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS
M965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR
M96%D(%]&2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@
M/2!U;G!A8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@
M;V8@1DE,17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)
M3$5?<V5C=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D
M(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E
M860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI
M;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-
M;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^
M("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F
M=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#
M(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF
M(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#
M86-H97LD;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F
M:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B
M.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD
M9F@M/G-E96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U
M9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL
M96YA;64B.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#
M*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE
M.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L
M:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA
M;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I
M*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@
M=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@
M;F4@)%!+6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R
M($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@
M("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D
M,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`
M05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@
M/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D
M:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY
M("5M971A7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II
M<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z
M)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>
M.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P
M87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L
M(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D
M8G5F(&5Q("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H
M)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z
M.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I
M;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@
M,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;BD@>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;CL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?
M1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@
M)#`I.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR
M97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@
M/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E
M)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS
M?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL
M97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@
M=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI
M8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E
M=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2![
M"FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I
M('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>
M+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE
M0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S
M=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D
M9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN
M960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@
M(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*
M;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F
M:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII
M9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE
M;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L
M("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O
M;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A
M)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA
M;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B
M+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX
M+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D
M;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O
M=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II
M9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP
M('!A<G0@;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD
M9F@M/G!R:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D
M8V%C:&5?;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*
M<V5E:R`D9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L
M(#`L(#(["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H
M95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S
M:7IE.PHD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE
M+`HB7#!#04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD
M4$%27TU!1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!T<F%I;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE
M>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX
M7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@
M;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII
M<#HZ<V5T0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G
M;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R
M;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z
M.EII<#HZ<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB
M0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP
M.PIO=71S*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M*%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^
M97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE
M;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE
M*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*
M57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@
M72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/
M;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G
M;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*
M;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H
M)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL
M97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*
M1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C
M(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S
M('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I
M;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q
M=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD[
M"G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E
M($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER
M92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ
M:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#
M87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L
M24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S
M971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR
M971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W
M*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@
M0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A
M=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM
M>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E
M9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I
M('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E
M9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*
M)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G
M4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD
M8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@
M(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O
M9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA
M9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,
M15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F
M.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F
M(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%
M7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M
M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*
M)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]
M"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER
M(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER
M("X]("(D<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A
M<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C
M;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E
M;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA
M;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A
M=R<L("1T96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC
M;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B
M.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D
M93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E
M;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N
M86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]
M"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S
M>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D
M)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.
M($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?
M)%\B?3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2![
M"B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X
M:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%
M35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#
M04-(10``<&5R;'AS:2YC`````````!0``````````7I2``%X$`$;#`<(D`$`
M`$P````<````D(W__\8`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$.
M.(,'1`Y``FP*#CA$#C!!#BA"#B!"#AA"#A!"#@A)"P``````)````&P````0
MCO__>P````!!#A"#`D<.(`)L"@X000X(00L``````$P```"4````:([__S<"
M````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D0..(,'1PY@`Q4!"@XX00XP
M00XH0@X@0@X80@X00@X(00L`````/````.0```!8D/__00$```!"#A"-`D(.
M&(P#00X@A@1!#BB#!4<.P`%Z"@XH00X@00X80@X00@X(0PL``````"0````D
M`0``:)'__U4`````00X0A@)0#AB#`T0.(&D.&$$.$%$."``D````3`$``*"1
M__^!`````$$.$(,"2@Z@`0)O"@X000X(00L`````/````'0!```(DO__V0``
M``!"#A"-`DH.&(P#20X@A@1!#BB#!4<.P`@"?PH.*$$.($$.&$(.$$(."$$+
M`````"P```"T`0``J)+__ZT`````00X0@P)*#J`(`F\*#A!!#@A%"UT*#A!&
M#@A%"P```!0```#D`0``*)/__R@``````````````!0```#\`0``0)/__P,`
M`````````````#P````4`@``.)/__^\!````0@X0C0)*#AB,`T$.((8$00XH
M@P5*#L`)`EP*#BA!#B!!#AA"#A!"#@A&"P`````<````5`(``.B4__\B````
M`$$.$(,"7`X(`````````"0```!T`@``^)3__T0`````2PX0@P)8PPX(70X0
M@P)##@@````````<````G`(``""5__]<`0```$0.(`,B`0H."$H+`````!P`
M``"\`@``8);__UD`````1`X@`DH*#@A""P``````%````-P"``"@EO__JP``
M``!'#N`!````-````/0"```XE___"@$```!"#A",`DL.&(8#00X@@P1'#K"`
M!`*Q"@X@00X800X00@X(1@L````4````+`,``!"8__\=`````$0.$%@."``T
M````1`,``!B8__^P`````$(.$(P"00X8A@-)#B"#!$0.,`)&"@X@00X800X0
M0@X(1@L``````%0```!\`P``D)C__XT&````0@X0C@)"#AB-`TH.((P$00XH
MA@5!#C"#!D<.@`,#E`(*#C!!#BA!#B!"#AA"#A!"#@A!"P.K`0Z(`TL.D`-;
M#H@#00Z``P`T````U`,``,B>__\#`@```$(.$(P"1@X8A@-!#B"#!$0.,`-I
M`0H.($$.&$$.$$(."$8+`````!P````,!```H*#__U$`````00X0@P)9"@X(
M1@ML#@@`)````"P$``#`A/__`0(```!!#A"#`D0.0`-=`0H.$$$."$$+````
M`$P```!4!```R*#__PP6````0@X0CP)&#AB.`T(.((T$0@XHC`5!#C"&!D$.
M.(,'1P[0!0/G%0H..$$.,$$.*$(.($(.&$(.$$(."$$+````%````*0$``"(
MMO__5`````!$#A`"3PX(9````+P$``#0MO__H`$```!"#A"/`D4.&(X#10X@
MC01"#BB,!40.,(8&1@XX@P='#D`"8`H..$$.,$$.*$(.($(.&$(.$$(."$<+
M`L0*#CA!#C!!#BA"#B!"#AA"#A!"#@A""P````!$````)`4```BX___U`0``
M`$(.$(X"1@X8C0-"#B",!$$.*(8%1`XP@P8#1@$*#BA$#B!"#AA"#A!"#@A%
M"P`````````````D````;`4``+!____0`P````X01@X82@\+=PB``#\:.RHS
M)"(```````````$;`SMH^O__'````(Q____4____7(/__Y3^__\<B/__A/K_
M_^R(___4^O__;(G___SZ__^LB___3/O___R,__^,^___7(W__[3[___LC?__
MW/O__\R.__\<_/__?(___TS\__^LC___9/S__[R/__]\_/__K)'__[S\___<
MD?__W/S__RR2__\$_?__C)/__R3]___LD___1/W__YR4__]<_?__K)7__Y3]
M___,E?__K/W__WR6___D_?__#)W__SS^__\<G___=/[__XR?__^\_O__G+7_
M_PS____\M?__)/___YRW__^,____`P````````!`JT````````(`````````
MH`4````````7`````````!@20```````%``````````'``````````<`````
M````H!%````````(`````````'@`````````"0`````````8`````````!4`
M```````````````````&`````````%`"0```````"P`````````8````````
M``4`````````(`M````````*`````````)P$````````]?[_;P````#`#T``
M``````$`````````&00````````!`````````"D$`````````0`````````Y
M!`````````$`````````1`0````````!`````````$X$`````````0``````
M``!<!`````````$`````````*``````````,`````````+@70```````#0``
M```````(4D```````!T`````````:00```````#P__]O`````+000```````
M_O__;P````!P$4```````/___V\``````0``````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````,*E`````````````````````````````YA=```````#V%T``
M``````880```````%AA````````F&$```````#880```````1AA```````!6
M&$```````&880```````=AA```````"&&$```````)880```````IAA`````
M``"V&$```````,880```````UAA```````#F&$```````/880```````!AE`
M```````6&4```````"890```````-AE```````!&&4```````%890```````
M9AE```````!V&4```````(890```````EAE```````"F&4```````+890```
M````QAE```````#6&4```````.890```````]AE````````&&D```````!8:
M0```````)AI````````V&D```````$8:0```````5AI```````!F&D``````
M`'8:0```````AAI```````"6&D```````*8:0```````MAI```````#&&D``
M`````-8:0```````YAI```````#V&D````````8;0```````%AM````````F
M&T```````#8;0```````1AM```````!6&T```````&8;0```````=AM`````
M``"&&T```````)8;0```````&%)```````````````````I005(N<&T*````
M```````H54```````/__________``````````#__________P``````````
M`$=#0SH@."XS(%M$<F%G;VY&;'E=(%)E;&5A<V4O,C`Q.2TP,BTR,@`````$
M````"0````0```!'3E4`9V]L9"`Q+C$V`````"YT97AT`"YG;W0`+F-O;6UE
M;G0`+F=O="YP;'0`+G)E;&$N<&QT`"YI;FET`"YB<W,`+F1T;W)S`"YC=&]R
M<P`N9'EN<W1R`"YE:%]F<F%M95]H9'(`+F=N=2YV97)S:6]N7W(`+FEN=&5R
M<``N<F5L82YD>6X`+F=N=2YV97)S:6]N`"YN;W1E+F=N=2YG;VQD+79E<G-I
M;VX`+F1Y;G-Y;0`N9FEN:0`N9VYU+FAA<V@`+FYO=&4N=&%G`"YE:%]F<F%M
M90`N=&U?8VQO;F5?=&%B;&4`+F1Y;F%M:6,`+G-H<W1R=&%B`"YR;V1A=&$`
M+F1A=&$`````````````````````````````````````````````````````
M``````````````````````````````````````````!F`````0````(`````
M``````)``````````@```````!4````````````````````!````````````
M````````M`````<````"`````````!@"0```````&`(````````X````````
M````````````!````````````````````)P````+`````@````````!0`D``
M`````%`"````````T`@````````$`````0````@`````````&`````````!!
M`````P````(`````````(`M````````@"P```````)P$````````````````
M```!````````````````````J@```/;__V\"`````````,`/0```````P`\`
M``````#T``````````,`````````"````````````````````'@```#___]O
M`@````````"T$$```````+00````````O``````````#``````````(`````
M`````@````````!7````_O__;P(`````````<!%```````!P$0```````#``
M````````!`````$````$````````````````````;@````0````"````````
M`*`10```````H!$```````!X``````````,`````````"``````````8````
M`````!X````$````0@`````````8$D```````!@2````````H`4````````#
M````"P````@`````````&``````````H`````0````8`````````N!=`````
M``"X%P```````!,````````````````````$````````````````````(P``
M``$````&`````````-`70```````T!<```````#0`P``````````````````
M$``````````0``````````$````!````!@````````"@&T```````*`;````
M````9S8``````````````````!````````````````````"D`````0````8`
M````````"%)````````(4@````````X````````````````````$````````
M````````````ZP````$````"`````````!A20```````&%(```````"20```
M````````````````"````````````````````+X````!``!P`@````````"P
MDD```````+"2````````E`4```````````````````@`````````````````
M``!)`````0``<`(`````````1)A```````!$F````````.P`````````````
M```````$````````````````````V`````8````#`````````#"I0```````
M,)D``````````@````````0`````````"``````````0``````````<````!
M`````P`````````PJT```````#";````````$`````````````````````@`
M```````````````````5`````0````,`````````0*M```````!`FP``````
M`/@!```````````````````(````````````````````\P````$````#````
M`````#BM0```````.)T````````H````````````````````"```````````
M`````````#H````!`````P````````!@K4```````&"=````````$```````
M``````````````@````````````````````S`````0````,`````````<*U`
M``````!PG0```````!`````````````````````(````````````````````
MR`````$````#`````````("M0```````@)T`````````````````````````
M````"````````````````````"X````(`````P````````"`K4```````("=
M````````H0```````````````````"`````````````````````,`````0``
M`#````````````````````"`G0```````"D````````````````````!````
M``````$`````````A0````<`````````````````````````K)T````````<
M````````````````````!````````````````````.$````#````````````
M`````````````,B=````````^0````````````````````$`````````````
%````````
